@@ -275,7 +275,11 @@ class SecureFlaskApp(Flask):
                                else jsonify(dict(message="Unauthorized")), 403
                 current_object = session.get("cas-object")
                 if current_object is None:
-                    session["cas-after-login"] = f"{request.path}{_parse_query_string(quoted=False)}"
+                    after_login = f"{request.path}{_parse_query_string(quoted=False)}"
+                    if after_login.startswith("http://"):
+                        after_login = after_login.replace("http://", "https://")
+                        
+                    session["cas-after-login"] = after_login
                     response = _login(self.__cas_server_url)
                 else:
                     cas = CasUser(current_object["user"], current_object["attributes"], db_session=self.db, user_table=self.users)
@@ -411,7 +415,6 @@ def _login(in_cas_url, db_session=None, security_user_table=None):
 
     cas_ticket = session.get("cas-ticket")
     if cas_ticket is not None:
-
         client = caslib.SAMLClient(in_cas_url, app_url)
         cas_response = client.saml_serviceValidate(session["cas-ticket"])
         if cas_response.success:
